@@ -1,4 +1,5 @@
 import abc
+import hashlib
 import re
 from collections import OrderedDict
 
@@ -88,16 +89,20 @@ class ResourceName:
         safe = safe.replace("${self:service}", self.service.service.spinal)
         safe = safe.replace("${sls:stage}", "staging")
 
-        if len(safe) > 64:
+        if len(safe) > 60:
             parts = []
             for part in self.name.split("-"):
                 if "$" in part or part == "lambda":
                     parts.append(part)
                 else:
                     parts.append(part[0:3])
-            return "-".join(parts)
+            name = "-".join(parts)
         else:
-            return self.name
+            name = self.name
+
+        name = name + "-" + hashlib.md5(safe.encode('utf-8')).hexdigest()[:5]
+
+        return name
 
 
 class ProviderMetadata(type(YamlOrderedDict), type(abc.ABC)):
